summaryrefslogtreecommitdiff
path: root/perl.h
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2003-08-04 05:10:57 +0000
committerJarkko Hietaniemi <jhi@iki.fi>2003-08-04 05:10:57 +0000
commit6239f2daa03877fbd4818ee3cd82a01a135ecb43 (patch)
tree2523480436b9c01c7227bcab2b6e2cf866ef8e7e /perl.h
parent63fae90782a9851db725590019f02999dc17a13e (diff)
downloadperl-6239f2daa03877fbd4818ee3cd82a01a135ecb43.tar.gz
Apparently the newly introduce -DDARWIN did conflict with
some Apple definition, how ironic... p4raw-id: //depot/perl@20467
Diffstat (limited to 'perl.h')
-rw-r--r--perl.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/perl.h b/perl.h
index 7f912e1f6d..8d12c2bbee 100644
--- a/perl.h
+++ b/perl.h
@@ -73,18 +73,18 @@
/* Use the reentrant APIs like localtime_r and getpwent_r */
/* Win32 has naturally threadsafe libraries, no need to use any _r variants. */
-#if defined(USE_ITHREADS) && !defined(USE_REENTRANT_API) && !defined(NETWARE) && !defined(WIN32) && !defined(DARWIN)
+#if defined(USE_ITHREADS) && !defined(USE_REENTRANT_API) && !defined(NETWARE) && !defined(WIN32) && !defined(PERL_DARWIN)
# define USE_REENTRANT_API
#endif
/* <--- here ends the logic shared by perl.h and makedef.pl */
/*
* DARWIN for MacOSX (__APPLE__ exists but is not officially sanctioned)
* (The -DDARWIN comes from the hints/darwin.sh.)
* __bsdi__ for BSD/OS
*/
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(DARWIN) || defined(__bsdi__) || defined(BSD41) || defined(BSD42) || defined(BSD43) || defined(BSD44)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(PERL_DARWIN) || defined(__bsdi__) || defined(BSD41) || defined(BSD42) || defined(BSD43) || defined(BSD44)
# ifndef BSDish
# define BSDish
# endif
@@ -2947,13 +2947,13 @@ typedef OP* (CPERLscope(*PPADDR_t)[]) (pTHX);
/* NeXT has problems with crt0.o globals */
#if defined(__DYNAMIC__) && \
- (defined(NeXT) || defined(__NeXT__) || defined(DARWIN))
+ (defined(NeXT) || defined(__NeXT__) || defined(PERL_DARWIN))
# if defined(NeXT) || defined(__NeXT)
# include <mach-o/dyld.h>
# define environ (*environ_pointer)
EXT char *** environ_pointer;
# else
-# if defined(DARWIN) && defined(PERL_CORE)
+# if defined(PERL_DARWIN) && defined(PERL_CORE)
# include <crt_externs.h> /* for the env array */
# define environ (*_NSGetEnviron())
# endif
@@ -73,18 +73,18 @@
/* <--- here ends the logic shared by perl.h and makedef.pl */
/*
- * DARWIN for MacOSX (__APPLE__ exists but is not officially sanctioned)
- * (The -DDARWIN comes from the hints/darwin.sh.)
+ * PERL_DARWIN for MacOSX (__APPLE__ exists but is not officially sanctioned)
+ * (The -DPERL_DARWIN comes from the hints/darwin.sh.)
* __bsdi__ for BSD/OS
*/